Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1282)

Unified Diff: lib/compiler/implementation/enqueue.dart

Issue 10977033: Cleanup the core/object.dart file. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | lib/compiler/implementation/lib/core.dart » ('j') | lib/core/object.dart » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/compiler/implementation/enqueue.dart
diff --git a/lib/compiler/implementation/enqueue.dart b/lib/compiler/implementation/enqueue.dart
index d1449cd9a29ce3fbc7bff8068ff15a644acf6d80..72122b389384d58940b7b78f0c35f93fc8afa006 100644
--- a/lib/compiler/implementation/enqueue.dart
+++ b/lib/compiler/implementation/enqueue.dart
@@ -128,8 +128,8 @@ class Enqueuer {
queue.add(new WorkItem(element, elements, itemCompilationContextCreator()));
- // Enable runtime type support if we discover a method called runtimeType.
- if (element.isFunction() && element.name == Compiler.RUNTIME_TYPE) {
+ // Enable runtime type support if we discover a getter called runtimeType.
+ if (element.isGetter() && element.name == Compiler.RUNTIME_TYPE) {
compiler.enabledRuntimeType = true;
}
« no previous file with comments | « no previous file | lib/compiler/implementation/lib/core.dart » ('j') | lib/core/object.dart » ('J')

Powered by Google App Engine
This is Rietveld 408576698